'''
Created on 29/09/2009

@author: Salvador
'''

import re

## A PatternList is a virtual list of those objects that
#  matches any pattern defined.
class PatternList:
    '''In a PatternList, an item is inside the PatternList if it
    matches any contained pattern'''
    
    ## Constructor lets developer to set the pattern list
    #  @param patterns list of patterns defined
    def __init__(self, patterns):
        '''Constructor can set the list of patterns'''
        self.pattern_list = patterns
        
    ## Lets the developer to use operator in.
    #  An item is contained by the PatternList if the item 
    #  matches any pattern defined
    #  @param item item to check if it is inside the list
    def __contains__(self, item):
        '''An item is contained by the PatternList if the item 
        matches any pattern defined'''
        for pattern in self.pattern_list:
            if re.match(pattern, item):
                return True
            
        return False
    
    ## Escape methacharacters in order to build a literal
    #  @param string string to be converted into a literal
    @staticmethod
    def literal(string):
        '''Escape methacharacters in order to build a literal'''
        return re.escape(string)
